@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2010-2012, 2014-2016 Free Software Foundation, Inc.
+   Copyright (C) 2010-2020 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -201,6 +201,9 @@ _iostream_ctl (struct _mu_stream *str, int code, int opcode, void *arg)
 	  return mu_stream_ioctl (sp->transport[qp->type], code, opcode, arg);
 	}
       
+    case MU_IOCTL_TCPSTREAM:
+      return mu_stream_ioctl (sp->transport[0], code, opcode, arg);
+      
     default:
       return ENOSYS;
     }
